@@ -16,7 +16,17 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
 
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
@@ -24,7 +34,8 @@ from google.api_core import retry as retries
 from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.appengine_admin_v1 import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -121,7 +132,7 @@ class ApplicationsAsyncClient:
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -157,9 +168,9 @@ class ApplicationsAsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, ApplicationsTransport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the applications client.
@@ -203,11 +214,11 @@ class ApplicationsAsyncClient:
 
     async def get_application(
         self,
-        request: Union[appengine.GetApplicationRequest, dict] = None,
+        request: Optional[Union[appengine.GetApplicationRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> application.Application:
         r"""Gets information about an application.
@@ -238,7 +249,7 @@ class ApplicationsAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.appengine_admin_v1.types.GetApplicationRequest, dict]):
+            request (Optional[Union[google.cloud.appengine_admin_v1.types.GetApplicationRequest, dict]]):
                 The request object. Request message for
                 `Applications.GetApplication`.
             name (:class:`str`):
@@ -305,10 +316,10 @@ class ApplicationsAsyncClient:
 
     async def create_application(
         self,
-        request: Union[appengine.CreateApplicationRequest, dict] = None,
+        request: Optional[Union[appengine.CreateApplicationRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Creates an App Engine application for a Google Cloud Platform
@@ -347,13 +358,13 @@ class ApplicationsAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.appengine_admin_v1.types.CreateApplicationRequest, dict]):
+            request (Optional[Union[google.cloud.appengine_admin_v1.types.CreateApplicationRequest, dict]]):
                 The request object. Request message for
                 `Applications.CreateApplication`.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -402,10 +413,10 @@ class ApplicationsAsyncClient:
 
     async def update_application(
         self,
-        request: Union[appengine.UpdateApplicationRequest, dict] = None,
+        request: Optional[Union[appengine.UpdateApplicationRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Updates the specified Application resource. You can update the
@@ -442,13 +453,13 @@ class ApplicationsAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.appengine_admin_v1.types.UpdateApplicationRequest, dict]):
+            request (Optional[Union[google.cloud.appengine_admin_v1.types.UpdateApplicationRequest, dict]]):
                 The request object. Request message for
                 `Applications.UpdateApplication`.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -503,10 +514,10 @@ class ApplicationsAsyncClient:
 
     async def repair_application(
         self,
-        request: Union[appengine.RepairApplicationRequest, dict] = None,
+        request: Optional[Union[appengine.RepairApplicationRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Recreates the required App Engine features for the specified App
@@ -545,13 +556,13 @@ class ApplicationsAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.appengine_admin_v1.types.RepairApplicationRequest, dict]):
+            request (Optional[Union[google.cloud.appengine_admin_v1.types.RepairApplicationRequest, dict]]):
                 The request object. Request message for
                 'Applications.RepairApplication'.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -611,14 +622,9 @@ class ApplicationsAsyncClient:
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-appengine-admin",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("ApplicationsAsyncClient",)
