@@ -827,7 +827,7 @@ class ApplicationsClient(metaclass=ApplicationsClientMeta):
         # Done; return the response.
         return response
 
-    def __enter__(self):
+    def __enter__(self) -> "ApplicationsClient":
         return self
 
     def __exit__(self, type, value, traceback):
