@@ -860,7 +860,7 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
             metadata=metadata,
         )
 
-    def __enter__(self):
+    def __enter__(self) -> "AuthorizedCertificatesClient":
         return self
 
     def __exit__(self, type, value, traceback):
