@@ -516,7 +516,7 @@ class AuthorizedDomainsClient(metaclass=AuthorizedDomainsClientMeta):
         # Done; return the response.
         return response
 
-    def __enter__(self):
+    def __enter__(self) -> "AuthorizedDomainsClient":
         return self
 
     def __exit__(self, type, value, traceback):
