@@ -897,7 +897,7 @@ class DomainMappingsClient(metaclass=DomainMappingsClientMeta):
         # Done; return the response.
         return response
 
-    def __enter__(self):
+    def __enter__(self) -> "DomainMappingsClient":
         return self
 
     def __exit__(self, type, value, traceback):
