@@ -16,7 +16,17 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
 
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
@@ -24,7 +34,8 @@ from google.api_core import retry as retries
 from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.appengine_admin_v1 import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -124,7 +135,7 @@ class FirewallAsyncClient:
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -160,9 +171,9 @@ class FirewallAsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, FirewallTransport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the firewall client.
@@ -206,10 +217,10 @@ class FirewallAsyncClient:
 
     async def list_ingress_rules(
         self,
-        request: Union[appengine.ListIngressRulesRequest, dict] = None,
+        request: Optional[Union[appengine.ListIngressRulesRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListIngressRulesAsyncPager:
         r"""Lists the firewall rules of an application.
@@ -241,7 +252,7 @@ class FirewallAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.appengine_admin_v1.types.ListIngressRulesRequest, dict]):
+            request (Optional[Union[google.cloud.appengine_admin_v1.types.ListIngressRulesRequest, dict]]):
                 The request object. Request message for
                 `Firewall.ListIngressRules`.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -297,10 +308,10 @@ class FirewallAsyncClient:
 
     async def batch_update_ingress_rules(
         self,
-        request: Union[appengine.BatchUpdateIngressRulesRequest, dict] = None,
+        request: Optional[Union[appengine.BatchUpdateIngressRulesRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> appengine.BatchUpdateIngressRulesResponse:
         r"""Replaces the entire firewall ruleset in one bulk operation. This
@@ -337,7 +348,7 @@ class FirewallAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.appengine_admin_v1.types.BatchUpdateIngressRulesRequest, dict]):
+            request (Optional[Union[google.cloud.appengine_admin_v1.types.BatchUpdateIngressRulesRequest, dict]]):
                 The request object. Request message for
                 `Firewall.BatchUpdateIngressRules`.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -380,10 +391,10 @@ class FirewallAsyncClient:
 
     async def create_ingress_rule(
         self,
-        request: Union[appengine.CreateIngressRuleRequest, dict] = None,
+        request: Optional[Union[appengine.CreateIngressRuleRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> firewall.FirewallRule:
         r"""Creates a firewall rule for the application.
@@ -414,7 +425,7 @@ class FirewallAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.appengine_admin_v1.types.CreateIngressRuleRequest, dict]):
+            request (Optional[Union[google.cloud.appengine_admin_v1.types.CreateIngressRuleRequest, dict]]):
                 The request object. Request message for
                 `Firewall.CreateIngressRule`.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -461,10 +472,10 @@ class FirewallAsyncClient:
 
     async def get_ingress_rule(
         self,
-        request: Union[appengine.GetIngressRuleRequest, dict] = None,
+        request: Optional[Union[appengine.GetIngressRuleRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> firewall.FirewallRule:
         r"""Gets the specified firewall rule.
@@ -495,7 +506,7 @@ class FirewallAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.appengine_admin_v1.types.GetIngressRuleRequest, dict]):
+            request (Optional[Union[google.cloud.appengine_admin_v1.types.GetIngressRuleRequest, dict]]):
                 The request object. Request message for
                 `Firewall.GetIngressRule`.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -542,10 +553,10 @@ class FirewallAsyncClient:
 
     async def update_ingress_rule(
         self,
-        request: Union[appengine.UpdateIngressRuleRequest, dict] = None,
+        request: Optional[Union[appengine.UpdateIngressRuleRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> firewall.FirewallRule:
         r"""Updates the specified firewall rule.
@@ -576,7 +587,7 @@ class FirewallAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.appengine_admin_v1.types.UpdateIngressRuleRequest, dict]):
+            request (Optional[Union[google.cloud.appengine_admin_v1.types.UpdateIngressRuleRequest, dict]]):
                 The request object. Request message for
                 `Firewall.UpdateIngressRule`.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -623,10 +634,10 @@ class FirewallAsyncClient:
 
     async def delete_ingress_rule(
         self,
-        request: Union[appengine.DeleteIngressRuleRequest, dict] = None,
+        request: Optional[Union[appengine.DeleteIngressRuleRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes the specified firewall rule.
@@ -654,7 +665,7 @@ class FirewallAsyncClient:
                 await client.delete_ingress_rule(request=request)
 
         Args:
-            request (Union[google.cloud.appengine_admin_v1.types.DeleteIngressRuleRequest, dict]):
+            request (Optional[Union[google.cloud.appengine_admin_v1.types.DeleteIngressRuleRequest, dict]]):
                 The request object. Request message for
                 `Firewall.DeleteIngressRule`.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -695,14 +706,9 @@ class FirewallAsyncClient:
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-appengine-admin",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("FirewallAsyncClient",)
