@@ -16,7 +16,17 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
 
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
@@ -24,7 +34,8 @@ from google.api_core import retry as retries
 from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.appengine_admin_v1 import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -123,7 +134,7 @@ class InstancesAsyncClient:
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -159,9 +170,9 @@ class InstancesAsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, InstancesTransport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the instances client.
@@ -205,10 +216,10 @@ class InstancesAsyncClient:
 
     async def list_instances(
         self,
-        request: Union[appengine.ListInstancesRequest, dict] = None,
+        request: Optional[Union[appengine.ListInstancesRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListInstancesAsyncPager:
         r"""Lists the instances of a version.
@@ -244,7 +255,7 @@ class InstancesAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.appengine_admin_v1.types.ListInstancesRequest, dict]):
+            request (Optional[Union[google.cloud.appengine_admin_v1.types.ListInstancesRequest, dict]]):
                 The request object. Request message for
                 `Instances.ListInstances`.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -300,10 +311,10 @@ class InstancesAsyncClient:
 
     async def get_instance(
         self,
-        request: Union[appengine.GetInstanceRequest, dict] = None,
+        request: Optional[Union[appengine.GetInstanceRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> instance.Instance:
         r"""Gets instance information.
@@ -334,7 +345,7 @@ class InstancesAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.appengine_admin_v1.types.GetInstanceRequest, dict]):
+            request (Optional[Union[google.cloud.appengine_admin_v1.types.GetInstanceRequest, dict]]):
                 The request object. Request message for
                 `Instances.GetInstance`.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -380,10 +391,10 @@ class InstancesAsyncClient:
 
     async def delete_instance(
         self,
-        request: Union[appengine.DeleteInstanceRequest, dict] = None,
+        request: Optional[Union[appengine.DeleteInstanceRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Stops a running instance.
@@ -426,13 +437,13 @@ class InstancesAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.appengine_admin_v1.types.DeleteInstanceRequest, dict]):
+            request (Optional[Union[google.cloud.appengine_admin_v1.types.DeleteInstanceRequest, dict]]):
                 The request object. Request message for
                 `Instances.DeleteInstance`.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -495,10 +506,10 @@ class InstancesAsyncClient:
 
     async def debug_instance(
         self,
-        request: Union[appengine.DebugInstanceRequest, dict] = None,
+        request: Optional[Union[appengine.DebugInstanceRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Enables debugging on a VM instance. This allows you
@@ -536,13 +547,13 @@ class InstancesAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.appengine_admin_v1.types.DebugInstanceRequest, dict]):
+            request (Optional[Union[google.cloud.appengine_admin_v1.types.DebugInstanceRequest, dict]]):
                 The request object. Request message for
                 `Instances.DebugInstance`.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -602,14 +613,9 @@ class InstancesAsyncClient:
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-appengine-admin",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("InstancesAsyncClient",)
