@@ -843,7 +843,7 @@ class InstancesClient(metaclass=InstancesClientMeta):
         # Done; return the response.
         return response
 
-    def __enter__(self):
+    def __enter__(self) -> "InstancesClient":
         return self
 
     def __exit__(self, type, value, traceback):
