@@ -16,7 +16,17 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
 
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
@@ -24,7 +34,8 @@ from google.api_core import retry as retries
 from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.appengine_admin_v1 import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -119,7 +130,7 @@ class ServicesAsyncClient:
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -155,9 +166,9 @@ class ServicesAsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, ServicesTransport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the services client.
@@ -201,10 +212,10 @@ class ServicesAsyncClient:
 
     async def list_services(
         self,
-        request: Union[appengine.ListServicesRequest, dict] = None,
+        request: Optional[Union[appengine.ListServicesRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListServicesAsyncPager:
         r"""Lists all the services in the application.
@@ -236,7 +247,7 @@ class ServicesAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.appengine_admin_v1.types.ListServicesRequest, dict]):
+            request (Optional[Union[google.cloud.appengine_admin_v1.types.ListServicesRequest, dict]]):
                 The request object. Request message for
                 `Services.ListServices`.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -292,10 +303,10 @@ class ServicesAsyncClient:
 
     async def get_service(
         self,
-        request: Union[appengine.GetServiceRequest, dict] = None,
+        request: Optional[Union[appengine.GetServiceRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> service.Service:
         r"""Gets the current configuration of the specified
@@ -327,7 +338,7 @@ class ServicesAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.appengine_admin_v1.types.GetServiceRequest, dict]):
+            request (Optional[Union[google.cloud.appengine_admin_v1.types.GetServiceRequest, dict]]):
                 The request object. Request message for
                 `Services.GetService`.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -382,10 +393,10 @@ class ServicesAsyncClient:
 
     async def update_service(
         self,
-        request: Union[appengine.UpdateServiceRequest, dict] = None,
+        request: Optional[Union[appengine.UpdateServiceRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Updates the configuration of the specified service.
@@ -414,13 +425,13 @@ class ServicesAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.appengine_admin_v1.types.UpdateServiceRequest, dict]):
+            request (Optional[Union[google.cloud.appengine_admin_v1.types.UpdateServiceRequest, dict]]):
                 The request object. Request message for
                 `Services.UpdateService`.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -482,10 +493,10 @@ class ServicesAsyncClient:
 
     async def delete_service(
         self,
-        request: Union[appengine.DeleteServiceRequest, dict] = None,
+        request: Optional[Union[appengine.DeleteServiceRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Deletes the specified service and all enclosed
@@ -515,13 +526,13 @@ class ServicesAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.appengine_admin_v1.types.DeleteServiceRequest, dict]):
+            request (Optional[Union[google.cloud.appengine_admin_v1.types.DeleteServiceRequest, dict]]):
                 The request object. Request message for
                 `Services.DeleteService`.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -589,14 +600,9 @@ class ServicesAsyncClient:
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-appengine-admin",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("ServicesAsyncClient",)
