@@ -810,7 +810,7 @@ class ServicesClient(metaclass=ServicesClientMeta):
         # Done; return the response.
         return response
 
-    def __enter__(self):
+    def __enter__(self) -> "ServicesClient":
         return self
 
     def __exit__(self, type, value, traceback):
