@@ -925,7 +925,7 @@ class VersionsClient(metaclass=VersionsClientMeta):
         # Done; return the response.
         return response
 
-    def __enter__(self):
+    def __enter__(self) -> "VersionsClient":
         return self
 
     def __exit__(self, type, value, traceback):
