@@ -92,7 +92,16 @@ class Instance(proto.Message):
     """
 
     class Availability(proto.Enum):
-        r"""Availability of the instance."""
+        r"""Availability of the instance.
+
+        Values:
+            UNSPECIFIED (0):
+
+            RESIDENT (1):
+
+            DYNAMIC (2):
+
+        """
         UNSPECIFIED = 0
         RESIDENT = 1
         DYNAMIC = 2
@@ -101,7 +110,36 @@ class Instance(proto.Message):
         r"""Wrapper for LivenessState enum."""
 
         class LivenessState(proto.Enum):
-            r"""Liveness health check status for Flex instances."""
+            r"""Liveness health check status for Flex instances.
+
+            Values:
+                LIVENESS_STATE_UNSPECIFIED (0):
+                    There is no liveness health check for the
+                    instance. Only applicable for instances in App
+                    Engine standard environment.
+                UNKNOWN (1):
+                    The health checking system is aware of the
+                    instance but its health is not known at the
+                    moment.
+                HEALTHY (2):
+                    The instance is reachable i.e. a connection
+                    to the application health checking endpoint can
+                    be established, and conforms to the requirements
+                    defined by the health check.
+                UNHEALTHY (3):
+                    The instance is reachable, but does not
+                    conform to the requirements defined by the
+                    health check.
+                DRAINING (4):
+                    The instance is being drained. The existing
+                    connections to the instance have time to
+                    complete, but the new ones are being refused.
+                TIMEOUT (5):
+                    The instance is unreachable i.e. a connection
+                    to the application health checking endpoint
+                    cannot be established, or the server does not
+                    respond within the specified timeout.
+            """
             LIVENESS_STATE_UNSPECIFIED = 0
             UNKNOWN = 1
             HEALTHY = 2
