@@ -22,40 +22,44 @@ try:
 except ImportError:  # pragma: NO COVER
     import mock
 
-import grpc
-from grpc.experimental import aio
 import math
-import pytest
-from proto.marshal.rules.dates import DurationRule, TimestampRule
-from proto.marshal.rules import wrappers
 
+from google.api_core import (
+    future,
+    gapic_v1,
+    grpc_helpers,
+    grpc_helpers_async,
+    operation,
+    operations_v1,
+    path_template,
+)
 from google.api_core import client_options
 from google.api_core import exceptions as core_exceptions
-from google.api_core import future
-from google.api_core import gapic_v1
-from google.api_core import grpc_helpers
-from google.api_core import grpc_helpers_async
-from google.api_core import operation
 from google.api_core import operation_async  # type: ignore
-from google.api_core import operations_v1
-from google.api_core import path_template
+import google.auth
 from google.auth import credentials as ga_credentials
 from google.auth.exceptions import MutualTLSChannelError
-from google.cloud.appengine_admin_v1.services.versions import VersionsAsyncClient
-from google.cloud.appengine_admin_v1.services.versions import VersionsClient
-from google.cloud.appengine_admin_v1.services.versions import pagers
-from google.cloud.appengine_admin_v1.services.versions import transports
-from google.cloud.appengine_admin_v1.types import app_yaml
-from google.cloud.appengine_admin_v1.types import appengine
-from google.cloud.appengine_admin_v1.types import deploy
-from google.cloud.appengine_admin_v1.types import operation as ga_operation
-from google.cloud.appengine_admin_v1.types import version
 from google.longrunning import operations_pb2
 from google.oauth2 import service_account
 from google.protobuf import duration_pb2  # type: ignore
+from google.protobuf import empty_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-import google.auth
+import grpc
+from grpc.experimental import aio
+from proto.marshal.rules import wrappers
+from proto.marshal.rules.dates import DurationRule, TimestampRule
+import pytest
+
+from google.cloud.appengine_admin_v1.services.versions import (
+    VersionsAsyncClient,
+    VersionsClient,
+    pagers,
+    transports,
+)
+from google.cloud.appengine_admin_v1.types import app_yaml, appengine, deploy
+from google.cloud.appengine_admin_v1.types import operation as ga_operation
+from google.cloud.appengine_admin_v1.types import version
 
 
 def client_cert_source_callback():
